@@ -30,81 +30,53 @@ class CoverageContextPlugin:
     address = attr.ib(init=False, default=None)
     running = attr.ib(init=False, default=False, hash=False)
 
-    @pytest.hookimpl(hookwrapper=True)
+    @pytest.hookimpl
     def pytest_collection(self):
         """
         Perform the collection phase for the given session.
         """
-        try:
-            self.switch_context("collection")
-            yield
-        finally:
-            self.switch_context(None)
+        self.switch_context("collection")
 
-    @pytest.hookimpl(hookwrapper=True)
+    @pytest.hookimpl
     def pytest_runtest_logstart(self, nodeid):
         """
         Called at the start of running the runtest protocol for a single item.
         """
-        try:
-            self.switch_context("{}|start".format(nodeid))
-            yield
-        finally:
-            self.switch_context(None)
+        self.switch_context("{}|start".format(nodeid))
 
-    @pytest.hookimpl(hookwrapper=True)
+    @pytest.hookimpl
     def pytest_runtest_setup(self, item):
         """
         Called to perform the setup phase for a test item.
         """
-        try:
-            self.switch_context("{}|setup".format(item.nodeid))
-            yield
-        finally:
-            self.switch_context(None)
+        self.switch_context("{}|setup".format(item.nodeid))
 
-    @pytest.hookimpl(hookwrapper=True)
+    @pytest.hookimpl
     def pytest_runtest_call(self, item):
         """
         Called to run the test for test item (the call phase).
         """
-        try:
-            self.switch_context("{}|call".format(item.nodeid))
-            yield
-        finally:
-            self.switch_context(None)
+        self.switch_context("{}|call".format(item.nodeid))
 
-    @pytest.hookimpl(hookwrapper=True)
+    @pytest.hookimpl
     def pytest_runtest_teardown(self, item):
         """
         Called to perform the teardown phase for a test item.
         """
-        try:
-            self.switch_context("{}|teardown".format(item.nodeid))
-            yield
-        finally:
-            self.switch_context(None)
+        self.switch_context("{}|teardown".format(item.nodeid))
 
-    @pytest.hookimpl(hookwrapper=True)
+    @pytest.hookimpl
     def pytest_runtest_logfinish(self, nodeid):
         """
         Called at the end of running the runtest protocol for a single item.
         """
-        try:
-            self.switch_context("{}|finish".format(nodeid))
-            yield
-        finally:
-            self.switch_context(None)
+        self.switch_context("{}|finish".format(nodeid))
 
     def switch_context(self, context):
         """
         Send the new dynamic context to PULL'ers
         """
-        if context is None:
-            log.debug("Resetting context")
-            context = "[{NONE}]"
-        else:
-            log.debug("Switching context to: %s", context)
+        log.debug("Switching coverage context to: %s", context)
         os.environ["COVERAGE_DYNAMIC_CONTEXT"] = context
         if self.pusher is not None:
             self.pusher.send_string(context)
@@ -117,7 +89,7 @@ class CoverageContextPlugin:
             return
 
         self.address = "tcp://127.0.0.1:{}".format(self.get_unused_localhost_port())
-        log.debug("Starting %s", self)
+        log.debug("%s is starting...", self)
         context = zmq.Context()
         pusher = context.socket(zmq.PUB)  # pylint: disable=no-member
         pusher.connect(self.address)
@@ -125,7 +97,7 @@ class CoverageContextPlugin:
         self.context = context
         self.pusher = pusher
         self.running = True
-        log.debug("%s is listening", self)
+        log.debug("%s started.", self)
 
     def stop(self):
         """
@@ -134,12 +106,13 @@ class CoverageContextPlugin:
         if self.running is False:
             return
 
-        log.debug("Stopping %s", self)
+        log.debug("%s is stopping...", self)
         self.running = False
         self.pusher.send_string("[{STOP}]")
         self.pusher.close(1500)
         self.context.term()
         self.pusher = self.context = self.running = None
+        log.debug("%s stopped.", self)
 
     @staticmethod
     def get_unused_localhost_port():
